==> apache-streampipes-0.93.0-source-release.zip: apache-streampipes-0.93.0/streampipes-extensions-management/src/test/java/org/apache/streampipes/extensions/management/connect/GuessManagementTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.extensions.management.connect;

import org.apache.streampipes.commons.exceptions.connect.AdapterException;
import org.apache.streampipes.extensions.management.init.IDeclarersSingleton;
import org.apache.streampipes.model.connect.adapter.AdapterDescription;

import org.junit.Test;
import org.mockito.Mockito;

import java.util.Optional;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.doReturn;
import static org.mockito.Mockito.when;

public class GuessManagementTest {

  @Test(expected = AdapterException.class)
  public void getAdapterGuessInfoAdapterNotFound() throws AdapterException {
    var mockDeclarersSingleton = Mockito.mock(IDeclarersSingleton.class);
    var guessManagement = Mockito.spy(GuessManagement.class);

    doReturn(mockDeclarersSingleton)
        .when(guessManagement)
        .getDeclarerSingleton();
    when(mockDeclarersSingleton.getAdapter(any()))
        .thenReturn(Optional.empty());

    guessManagement.guessSchema(new AdapterDescription());
  }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-extensions-management/src/test/java/org/apache/streampipes/extensions/management/connect/GuessManagementTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.extensions.management.connect;

import org.apache.streampipes.commons.exceptions.connect.AdapterException;
import org.apache.streampipes.extensions.management.init.IDeclarersSingleton;
import org.apache.streampipes.model.connect.adapter.AdapterDescription;

import org.junit.jupiter.api.Test;
import org.mockito.Mockito;

import java.util.Optional;

import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.doReturn;
import static org.mockito.Mockito.when;

public class GuessManagementTest {

  @Test
  public void getAdapterGuessInfoAdapterNotFound() {
    var mockDeclarersSingleton = Mockito.mock(IDeclarersSingleton.class);
    var guessManagement = Mockito.spy(GuessManagement.class);

    doReturn(mockDeclarersSingleton)
        .when(guessManagement)
        .getDeclarerSingleton();
    when(mockDeclarersSingleton.getAdapter(any()))
        .thenReturn(Optional.empty());

    assertThrows(AdapterException.class, () -> guessManagement.guessSchema(new AdapterDescription()));

  }
}
